# Neural Networks for Microcontrollers: Python

A python nn4mc package that allows for the translation of trained neural network models in C code for use in embedded systems.

### Development Status

Please note that nn4mc_py is still in development and may have many bugs. We are working hard on getting everything operating seamlessly, and feel free to reach out with any questions.
